==> ark-17.07.90.tar.xz: ark-17.07.90/plugins/libsinglefileplugin/kerfuffle_libbz2.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the bzip2 algorithm",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «bzip2»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «bzip2»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem bzip2",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem Bzip2-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο bzip2",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo bzip2",
        "Description[eu]": "Ireki eta erauzi bzip2 algoritmoarekin konprimatutako fitxategiak banaka",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme bzip2",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo bzip2",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het bzip2-algoritme",
        "Description[pl]": "Otwieraj i wypakowuj pojedyncze pliki spakowane algorytmem bzip2",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo Bzip2",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom bzip2",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom bzip2",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом бзип2",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom bzip2",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom bzip2",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом бзип2",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med bzip2-algoritmen",
        "Description[tr]": "Bzip2 algoritması ile sıkıştırılmış tek dosyaları açma ve çıkarma",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму bzip2",
        "Description[x-test]": "xxOpen and extract single files compressed with the bzip2 algorithmxx",
        "Description[zh_CN]": "打开和解压 bzip2 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 bzip2 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libbz2",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Bzip2 plugin",
        "Name[ca@valencia]": "Connector del Bzip2",
        "Name[ca]": "Connector del Bzip2",
        "Name[cs]": "Modul pro bzip2",
        "Name[de]": "Bzip2-Modul",
        "Name[el]": "Πρόσθετο Bzip2",
        "Name[es]": "Complemento Bzip2",
        "Name[eu]": "Bzip2 plugina",
        "Name[fr]": "Module externe d'archive « bzip2 »",
        "Name[it]": "Estensione Bzip2",
        "Name[nl]": "Bzip2-plug-in",
        "Name[pl]": "Wtyczka bzip2",
        "Name[pt]": "'Plugin' do Bzip2",
        "Name[sk]": "Plugin Bzip2",
        "Name[sl]": "Vstavek Bzip2",
        "Name[sr@ijekavian]": "Прикључак за бзип2",
        "Name[sr@ijekavianlatin]": "Priključak za bzip2",
        "Name[sr@latin]": "Priključak za bzip2",
        "Name[sr]": "Прикључак за бзип2",
        "Name[sv]": "Bzip2-insticksprogram",
        "Name[tr]": "Bzip2 eklentisi",
        "Name[uk]": "Додаток bzip2",
        "Name[x-test]": "xxBzip2 pluginxx",
        "Name[zh_CN]": "Bzip2 插件",
        "Name[zh_TW]": "Bzip2 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Priority": 100
}

==> ark-17.11.80.tar.xz: ark-17.11.80/plugins/libsinglefileplugin/kerfuffle_libbz2.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract single files compressed with the bzip2 algorithm",
        "Description[ca@valencia]": "Obri i extreu fitxers individuals comprimits amb l'algorisme «bzip2»",
        "Description[ca]": "Obre i extreu fitxers individuals comprimits amb l'algorisme «bzip2»",
        "Description[cs]": "Otevřít a rozbalit jednotlivé soubory komprimované algoritmem bzip2",
        "Description[de]": "Öffnen und Entpacken von einzelnen mit dem Bzip2-Algorithmus komprimierten Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή απλών αρχείων συμπιεσμένα με τον αλγόριθμο bzip2",
        "Description[es]": "Abrir y extraer archivos individuales comprimidos con el algoritmo bzip2",
        "Description[eu]": "Ireki eta erauzi bzip2 algoritmoarekin konprimatutako fitxategiak banaka",
        "Description[fr]": "Ouvre et extrait des fichiers compressés avec l'algorithme bzip2",
        "Description[gl]": "Abrir e extraer ficheiros individuais comprimidos co algoritmo bzip2.",
        "Description[it]": "Apri ed estrai singoli file compressi con l'algoritmo bzip2",
        "Description[nl]": "Open en pak uit losse bestanden gecomprimeerd met het bzip2-algoritme",
        "Description[nn]": "Opna og pakk ut einskildfiler komprimerte med bzip2-algoritmen",
        "Description[pl]": "Otwieraj i wypakowuj pojedyncze pliki spakowane algorytmem bzip2",
        "Description[pt]": "Abrir e extrair ficheiros individuais comprimidos com o algoritmo Bzip2",
        "Description[ru]": "Открытие и распаковка отдельных файлов, сжатых по алгоритму bzip2",
        "Description[sk]": "Otvorenie a extrahovanie jednotlivých súborov komprimovaných algoritmom bzip2",
        "Description[sl]": "Odprite in razširite datoteke stisnjene z algoritmom bzip2",
        "Description[sr@ijekavian]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом бзип2",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom bzip2",
        "Description[sr@latin]": "Otvaranje i raspakivanje pojedinačnih fajlova kompresovanih algoritmom bzip2",
        "Description[sr]": "Отварање и распакивање појединачних фајлова компресованих алгоритмом бзип2",
        "Description[sv]": "Öppna och packa upp enstaka filer komprimerade med bzip2-algoritmen",
        "Description[tr]": "Bzip2 algoritması ile sıkıştırılmış tek dosyaları açma ve çıkarma",
        "Description[uk]": "Здатен відкривати і видобувати дані із окремих файлів, стиснених за допомогою алгоритму bzip2",
        "Description[x-test]": "xxOpen and extract single files compressed with the bzip2 algorithmxx",
        "Description[zh_CN]": "打开和解压 bzip2 算法压缩的单个文件",
        "Description[zh_TW]": "開啟並解壓縮以 bzip2 演算法壓縮的單一檔案",
        "Id": "kerfuffle_libbz2",
        "MimeTypes": [
            "@SUPPORTED_MIMETYPES@"
        ],
        "Name": "Bzip2 plugin",
        "Name[ca@valencia]": "Connector del Bzip2",
        "Name[ca]": "Connector del Bzip2",
        "Name[cs]": "Modul pro bzip2",
        "Name[de]": "Bzip2-Modul",
        "Name[el]": "Πρόσθετο Bzip2",
        "Name[es]": "Complemento Bzip2",
        "Name[eu]": "Bzip2 plugina",
        "Name[fr]": "Module externe d'archive « bzip2 »",
        "Name[gl]": "Complemento de bzip2",
        "Name[it]": "Estensione Bzip2",
        "Name[nl]": "Bzip2-plug-in",
        "Name[nn]": "Bzip2-tillegg",
        "Name[pl]": "Wtyczka bzip2",
        "Name[pt]": "'Plugin' do Bzip2",
        "Name[ru]": "Модуль Bzip2",
        "Name[sk]": "Plugin Bzip2",
        "Name[sl]": "Vstavek Bzip2",
        "Name[sr@ijekavian]": "Прикључак за бзип2",
        "Name[sr@ijekavianlatin]": "Priključak za bzip2",
        "Name[sr@latin]": "Priključak za bzip2",
        "Name[sr]": "Прикључак за бзип2",
        "Name[sv]": "Bzip2-insticksprogram",
        "Name[tr]": "Bzip2 eklentisi",
        "Name[uk]": "Додаток bzip2",
        "Name[x-test]": "xxBzip2 pluginxx",
        "Name[zh_CN]": "Bzip2 插件",
        "Name[zh_TW]": "Bzip2 外掛程式",
        "ServiceTypes": [
            "Kerfuffle/Plugin"
        ],
        "Version": "@KDE_APPLICATIONS_VERSION@"
    },
    "X-KDE-Priority": 100
}
